@@ -56,7 +56,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelCreateFlowByFiles(self, request):
-        """接口（ChannelCreateFlowByFiles）用于渠道版通过文件创建流程。此接口不可直接使用，需要运营申请
+        """接口（ChannelCreateFlowByFiles）用于渠道版通过文件创建签署流程。此接口不可直接使用，需要运营申请
 
         :param request: Request instance for ChannelCreateFlowByFiles.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.ChannelCreateFlowByFilesRequest`
@@ -85,7 +85,7 @@ class EssbasicClient(AbstractClient):
 
 
     def ChannelCreateMultiFlowSignQRCode(self, request):
-        """此接口（ChannelCreateMultiFlowSignQRCode）用于创建一码多扫流程签署二维码。
+        """此接口（ChannelCreateMultiFlowSignQRCode）用于创建一码多扫签署流程二维码。
         适用的模版仅限于B2C（1、无序签署，2、顺序签署时B静默签署，3、顺序签署时B非首位签署）、单C的模版，且模版中发起方没有填写控件。
 
         :param request: Request instance for ChannelCreateMultiFlowSignQRCode.
@@ -144,7 +144,7 @@ class EssbasicClient(AbstractClient):
 
 
     def CreateFlowsByTemplates(self, request):
-        """接口（CreateFlowsByTemplates）用于使用多个模板批量创建流程。当前可批量发起合同（流程）数量最大为20个。
+        """接口（CreateFlowsByTemplates）用于使用多个模板批量创建签署流程。当前可批量发起合同（签署流程）数量最大为20个。
 
         :param request: Request instance for CreateFlowsByTemplates.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateFlowsByTemplatesRequest`
@@ -202,7 +202,7 @@ class EssbasicClient(AbstractClient):
 
 
     def CreateSignUrls(self, request):
-        """创建参与者签署短链
+        """创建跳转小程序查看或签署的链接
 
         :param request: Request instance for CreateSignUrls.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.CreateSignUrlsRequest`
@@ -231,7 +231,7 @@ class EssbasicClient(AbstractClient):
 
 
     def DescribeFlowDetailInfo(self, request):
-        """此接口（DescribeFlowDetailInfo）用于查询合同(流程)的详细信息。
+        """此接口（DescribeFlowDetailInfo）用于查询合同(签署流程)的详细信息。
 
         :param request: Request instance for DescribeFlowDetailInfo.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.DescribeFlowDetailInfoRequest`
@@ -260,8 +260,8 @@ class EssbasicClient(AbstractClient):
 
 
     def DescribeResourceUrlsByFlows(self, request):
-        """根据流程信息批量获取资源下载链接，可直接下载
-        限制：只能下载合作企业授权过的、单方签署的流程文件（若合作企业与渠道是同一企业，可以下载所有流程文件）
+        """根据签署流程信息批量获取资源下载链接，可直接下载
+        限制：只能下载合作企业授权过的、单方签署的签署流程文件（若合作企业与渠道是同一企业，可以下载所有签署流程文件）
 
         :param request: Request instance for DescribeResourceUrlsByFlows.
         :type request: :class:`tencentcloud.essbasic.v20210526.models.DescribeResourceUrlsByFlowsRequest`
@@ -413,7 +413,7 @@ class EssbasicClient(AbstractClient):
 
     def PrepareFlows(self, request):
         """该接口 (PrepareFlows) 用于创建待发起文件
-        用户通过该接口进入流程发起的确认页面，进行发起信息二次确认， 如果确认则进行正常发起。
+        用户通过该接口进入签署流程发起的确认页面，进行发起信息二次确认， 如果确认则进行正常发起。
         目前该接口只支持B2C，不建议使用。
 
         :param request: Request instance for PrepareFlows.
